@@ -1,6 +1,8 @@
 
 from uuid import uuid4
 
+from django.contrib.auth import authenticate, login
+from django.contrib.auth.models import User
 from django import forms
 from django.forms.extras.widgets import SelectDateWidget
 from django.utils.safestring import mark_safe
@@ -8,12 +10,6 @@ from django.utils.translation import ugettext_lazy as _
 
 from mezzanine.conf import settings
 from mezzanine.core.models import Orderable
-from mezzanine.utils.urls import content_media_urls
-
-
-tinymce_main = [settings.ADMIN_MEDIA_PREFIX +
-                "tinymce/jscripts/tiny_mce/tiny_mce.js"]
-tinymce_setup = content_media_urls("js/tinymce_setup.js")
 
 
 class TinyMceWidget(forms.Textarea):
@@ -23,13 +19,74 @@ class TinyMceWidget(forms.Textarea):
     """
 
     class Media:
-        js = tinymce_main + tinymce_setup
+        js = (settings.ADMIN_MEDIA_PREFIX +
+              "tinymce/jscripts/tiny_mce/tiny_mce.js",
+              settings.TINYMCE_SETUP_JS,)
 
     def __init__(self, *args, **kwargs):
         super(TinyMceWidget, self).__init__(*args, **kwargs)
         self.attrs["class"] = "mceEditor"
 
 
+class UserForm(forms.Form):
+    """
+    Fields for signup & login.
+    """
+    email = forms.EmailField(label=_("Email Address"))
+    password = forms.CharField(label=_("Password"),
+        widget=forms.PasswordInput(render_value=False))
+
+    def authenticate(self):
+        """
+        Validate email and password as well as setting the user for login.
+        """
+        self._user = authenticate(username=self.cleaned_data.get("email", ""),
+                               password=self.cleaned_data.get("password", ""))
+
+    def login(self, request):
+        """
+        Log the user in.
+        """
+        login(request, self._user)
+
+
+class SignupForm(UserForm):
+
+    def clean_email(self):
+        """
+        Ensure the email address is not already registered.
+        """
+        email = self.cleaned_data["email"]
+        try:
+            User.objects.get(username=email)
+        except User.DoesNotExist:
+            return email
+        raise forms.ValidationError(_("This email is already registered"))
+
+    def save(self):
+        """
+        Create the new user using their email address as their username.
+        """
+        User.objects.create_user(self.cleaned_data["email"],
+            self.cleaned_data["email"], self.cleaned_data["password"])
+        self.authenticate()
+
+
+class LoginForm(UserForm):
+
+    def clean(self):
+        """
+        Authenticate the email/password.
+        """
+        if "email" in self.cleaned_data and "password" in self.cleaned_data:
+            self.authenticate()
+            if self._user is None:
+                raise forms.ValidationError(_("Invalid email/password"))
+            elif not self._user.is_active:
+                raise forms.ValidationError(_("Your account is inactive"))
+        return self.cleaned_data
+
+
 class OrderWidget(forms.HiddenInput):
     """
     Add up and down arrows for ordering controls next to a hidden
@@ -50,8 +107,8 @@ class DynamicInlineAdminForm(forms.ModelForm):
     """
 
     class Media:
-        js = content_media_urls("js/jquery-ui-1.8.14.custom.min.js",
-                                "js/dynamic_inline.js",)
+        js = ("mezzanine/js/jquery-ui-1.8.14.custom.min.js",
+              "mezzanine/js/admin/dynamic_inline.js",)
 
     def __init__(self, *args, **kwargs):
         super(DynamicInlineAdminForm, self).__init__(*args, **kwargs)
@@ -66,7 +123,6 @@ class SplitSelectDateTimeWidget(forms.SplitDateTimeWidget):
     """
     def __init__(self, attrs=None, date_format=None, time_format=None):
         date_widget = SelectDateWidget(attrs=attrs)
-        time_format = forms.SplitDateTimeWidget.time_format
         time_widget = forms.TimeInput(attrs=attrs, format=time_format)
         forms.MultiWidget.__init__(self, (date_widget, time_widget), attrs)
 
